@@ -1,5 +1,6 @@
  mu0 <- function(lambda, delta, N=NULL, eps=sqrt(.Machine$double.eps)){
-        if (lambda <= 0) stop("valid only for lambda > 0")
+        #stopifnot (lambda >= 0)
+        if(lambda < 0) stop("touchard:::mu cannot compute with negative lambda")
         t0        <- tau(lambda,delta,N,eps)
         m0        <- tau(lambda,delta+1,N,eps)/t0
         return(m0 - 1)
